Welcome to jkUnicode's documentation!
=====================================

The jkUnicode module contains information about glyph names from the Adobe Glyph List, Unicode values and their properties from the Unicode standard, and orthography information from the Unicode Common Locale Database Repository (CLDR).

Included are scripts and tools to update and convert the source data. You can also customize the data which the Python modules use by supplying your own override files.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   uniinfo
   orthography
   aglfn
   uniRangesBits
   customizing
   scripts

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
